pub enum ChannelFilter {
ChannelId(ChannelId),
DestinationKeyId(KeyId),
SourceKeyId(KeyId),
SourceAndDestinationKeyIds(KeyId, KeyId),
}Expand description
Filters Channel records by channel id, source key id, destination key id, or both endpoint key
ids.
Variants
ChannelId(ChannelId)
Select a channel by its channel id.
DestinationKeyId(KeyId)
Select channels by its destination key id.
SourceKeyId(KeyId)
Select channels by its source key id.
SourceAndDestinationKeyIds(KeyId, KeyId)
Select channels by both source and destination key id.