pub enum SafeSelector {
SafeAddress(ChainAddress),
Owner(ChainAddress),
ChainKey(ChainAddress),
RegisteredNode(ChainAddress),
}Expand description
Selects deployed Safe records by safe address, owner, chain key alias, or registered node.
Variants
SafeAddress(ChainAddress)
Select a safe by its address.
Owner(ChainAddress)
Select a safe by a current owner address.
ChainKey(ChainAddress)
Select a safe by the owner’s chain key legacy alias.
RegisteredNode(ChainAddress)
Select a safe by any of the registered nodes.