pub struct ChainInfo {Show 16 fields
pub channel_closure_grace_period: Uint64,
pub channel_dst: Option<String>,
pub block_number: i32,
pub chain_id: i32,
pub gas_price: Option<String>,
pub ledger_dst: Option<String>,
pub max_fee_per_gas: Option<String>,
pub max_priority_fee_per_gas: Option<String>,
pub min_ticket_winning_probability: f64,
pub key_binding_fee: TokenValueString,
pub safe_registry_dst: Option<String>,
pub ticket_price: TokenValueString,
pub network: String,
pub contract_addresses: ContractAddressMap,
pub expected_block_time: Uint64,
pub finality: Uint64,
}Expand description
Chain, contract, fee, and ticket parameters reported by Blokli.
Fields
channel_closure_grace_period: Uint64Channel closure grace period in chain units reported by Blokli.
channel_dst: Option<String>Deployed channel contract address, when available.
block_number: i32Latest block number indexed or observed by Blokli.
chain_id: i32Numeric chain id.
gas_price: Option<String>Legacy gas price value, when supplied by the chain.
ledger_dst: Option<String>Deployed ledger contract address, when available.
max_fee_per_gas: Option<String>Current EIP-1559 max fee per gas, when supplied by the chain.
max_priority_fee_per_gas: Option<String>Current EIP-1559 max priority fee per gas, when supplied by the chain.
min_ticket_winning_probability: f64Minimum winning probability accepted for tickets.
key_binding_fee: TokenValueStringFee required for key binding.
safe_registry_dst: Option<String>Deployed safe registry contract address, when available.
ticket_price: TokenValueStringCurrent ticket price.
network: StringHuman-readable network name.
contract_addresses: ContractAddressMapMap of known contract addresses encoded by the GraphQL API.
expected_block_time: Uint64Expected block time in chain units reported by Blokli.
finality: Uint64Finality depth in blocks reported by Blokli.