pub struct CurvyEventPosition {
pub transaction_hash: Hex32,
pub block_hash: Hex32,
pub block: Uint64,
pub transaction_index: Uint64,
pub log_index: Uint64,
pub event_item_index: Uint64,
}Expand description
Canonical chain position and transaction identity for a Curvy event item.
Fields
transaction_hash: Hex32block_hash: Hex32block: Uint64transaction_index: Uint64log_index: Uint64event_item_index: Uint64Trait Implementations
Sourceimpl Clone for CurvyEventPosition
impl Clone for CurvyEventPosition
Sourcefn clone(&self) -> CurvyEventPosition
fn clone(&self) -> CurvyEventPosition
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CurvyEventPosition
impl Debug for CurvyEventPosition
Sourceimpl<'de> Deserialize<'de> for CurvyEventPosition
impl<'de> Deserialize<'de> for CurvyEventPosition
Sourcefn deserialize<__D>(deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for CurvyEventPosition
Sourceimpl From<&CurvyEventPosition> for CurvyEventCursor
impl From<&CurvyEventPosition> for CurvyEventCursor
Sourcefn from(position: &CurvyEventPosition) -> Self
fn from(position: &CurvyEventPosition) -> Self
Converts to this type from the input type.
Sourceimpl PartialEq for CurvyEventPosition
impl PartialEq for CurvyEventPosition
Sourceimpl QueryFragment for CurvyEventPosition
impl QueryFragment for CurvyEventPosition
Sourcetype SchemaType = CurvyEventPosition
type SchemaType = CurvyEventPosition
The type in a schema that this
QueryFragment representsSourcetype VariablesFields = ()
type VariablesFields = ()
The variables that are required to execute this
QueryFragmentSourcefn query(builder: SelectionBuilder<'_, Self::SchemaType, Self::VariablesFields>)
fn query(builder: SelectionBuilder<'_, Self::SchemaType, Self::VariablesFields>)
Adds this fragment to the query being built by
builderSourceimpl Serialize for CurvyEventPosition
impl Serialize for CurvyEventPosition
impl StructuralPartialEq for CurvyEventPosition