GraphQlQueries

Struct GraphQlQueries 

pub struct GraphQlQueries;
Contains all GraphQL queries used by the Blokli client.

Implementations

Source

impl GraphQlQueries

pub fn query_curvy_pending_notes( from_block: Option<u64>, after: Option<CurvyEventCursor>, first: u32, ) -> Result<Operation<QueryCurvyPendingNotes, CurvyEventPageVariables>, BlokliClientError>

Paginated pending Curvy note query.

pub fn query_curvy_committed_notes( from_block: Option<u64>, after: Option<CurvyEventCursor>, first: u32, ) -> Result<Operation<QueryCurvyCommittedNotes, CurvyEventPageVariables>, BlokliClientError>

Paginated committed Curvy note query.

pub fn query_curvy_committed_nullifiers( from_block: Option<u64>, after: Option<CurvyEventCursor>, first: u32, ) -> Result<Operation<QueryCurvyCommittedNullifiers, CurvyEventPageVariables>, BlokliClientError>

Paginated committed Curvy nullifier query.

pub fn query_curvy_sync_checkpoint( block_hash: Option<String>, ) -> Operation<QueryCurvySyncCheckpoint, CurvyCheckpointVariables>

pub fn query_curvy_sync_notes( checkpoint: String, from_index: Option<u64>, first: u32, ) -> Result<Operation<QueryCurvySyncNotes, CurvySyncPageVariables>, BlokliClientError>

pub fn query_curvy_sync_nullifiers( checkpoint: String, from_index: Option<u64>, first: u32, ) -> Result<Operation<QueryCurvySyncNullifiers, CurvySyncPageVariables>, BlokliClientError>

pub fn query_curvy_shard_roots( checkpoint: String, from_index: Option<u64>, first: u32, ) -> Result<Operation<QueryCurvyShardRoots, CurvySyncPageVariables>, BlokliClientError>

pub fn query_curvy_aggregator_state() -> Operation<QueryCurvyAggregatorState, ()>

pub fn query_curvy_note_status( note_id: String, ) -> Operation<QueryCurvyNoteStatus, CurvyNoteIdVariables>

pub fn query_curvy_valid_notes_root( root: String, ) -> Operation<QueryCurvyValidNotesRoot, CurvyRootVariables>

pub fn query_curvy_nullifier_spent( nullifier: String, ) -> Operation<QueryCurvyNullifierSpent, CurvyNullifierVariables>

pub fn query_curvy_vault_fees() -> Operation<QueryCurvyVaultFees, ()>

pub fn query_curvy_aggregator_fees() -> Operation<QueryCurvyAggregatorFees, ()>

pub fn query_curvy_vault_token_count() -> Operation<QueryCurvyVaultTokenCount, ()>

pub fn query_curvy_vault_token( token_id: String, ) -> Operation<QueryCurvyVaultToken, CurvyVaultTokenVariables>

pub fn query_curvy_entry_portal_address( owner_hash: String, recovery: String, ) -> Operation<QueryCurvyEntryPortalAddress, CurvyEntryPortalVariables>

pub fn query_curvy_exit_portal_address( exit_address: String, exit_chain_id: String, recovery: String, ) -> Operation<QueryCurvyExitPortalAddress, CurvyExitPortalVariables>

pub fn query_curvy_portal_registered( portal_address: String, ) -> Operation<QueryCurvyPortalRegistered, CurvyPortalVariables>

Source

impl GraphQlQueries

pub fn count_accounts( selector: AccountSelector, ) -> Operation<QueryAccountCount, AccountVariables>

AccountCount GraphQL query.

pub fn query_accounts( selector: AccountSelector, ) -> Operation<QueryAccounts, AccountVariables>

Accounts GraphQL query.

pub fn query_native_balance( address: &ChainAddress, ) -> Operation<QueryNativeBalance, BalanceVariables>

NativeBalance GraphQL query.

pub fn query_token_balance( address: &ChainAddress, token: Token, ) -> Operation<QueryHoprBalance, BalanceVariables>

TokenBalance GraphQL query.

pub fn query_transaction_count( address: &ChainAddress, ) -> Operation<QueryTxCount, TxCountVariables>

TransactionCount GraphQL query.

pub fn query_safe_allowance( address: &ChainAddress, ) -> Operation<QuerySafeAllowance, BalanceVariables>

SafeAllowance GraphQL query.

pub fn query_redeemed_stats( selector: RedeemedStatsSelector, ) -> Operation<QueryRedeemedStats, RedeemedStatsVariables>

TicketRedemptionStats GraphQL query.

pub fn query_safe_by( selector: SafeSelectorInput, address: &ChainAddress, ) -> Operation<QuerySafeBy, SafeByVariables>

safeBy GraphQL query.

pub fn query_module_address_prediction( input: ModulePredictionInput, ) -> Operation<QueryModuleAddress, ModuleAddressVariables>

ModuleAddressPrediction GraphQL query.

pub fn query_channel_count( selector: ChannelSelector, ) -> Operation<QueryChannelCount, ChannelsVariables>

👎Deprecated:

Use query_channel_stats instead, which returns both count and total wxHOPR balance.

ChannelCount GraphQL query.

pub fn query_channel_stats( selector: ChannelSelector, ) -> Operation<QueryChannelStats, ChannelStatsVariables>

ChannelStats GraphQL query.

pub fn query_channels( selector: ChannelSelector, ) -> Operation<QueryChannels, ChannelsVariables>

Channels GraphQL query.

pub fn query_safes_balance( owner_address: Option<ChainAddress>, ) -> Operation<QuerySafesBalance, SafesBalanceVariables>

SafesBalance GraphQL query.

pub fn count_services( selector: ServiceSelector, ) -> Operation<QueryServiceCount, ServiceVariables>

ServiceCount GraphQL query.

pub fn query_services( selector: ServiceSelector, after: Option<Uint64>, watermark: Option<Uint64>, live_only: bool, ) -> Operation<QueryServices, ServicePageVariables>

Services GraphQL query.

pub fn query_service_types( service_type: Option<ServiceTypeId>, ) -> Operation<QueryServiceTypes, ServiceTypeVariables>

ServiceTypes GraphQL query.

pub fn query_service_registry_config() -> Operation<QueryServiceRegistryConfig, ()>

ServiceRegistryConfig GraphQL query.

pub fn query_transaction( id: TxId, ) -> Operation<QueryTransaction, TransactionsVariables>

Transaction GraphQL query.

pub fn query_chain_info() -> Operation<QueryChainInfo, ()>

ChainInfo GraphQL query.

pub fn query_version() -> Operation<QueryVersion, ()>

Version GraphQL query.

pub fn query_health() -> Operation<QueryHealth, ()>

Health GraphQL query.

pub fn query_compatibility() -> Operation<QueryCompatibility, ()>

Compatibility GraphQL query.

Source

impl GraphQlQueries

pub fn subscribe_channels( selector: ChannelSelector, ) -> StreamingOperation<SubscribeChannels, ChannelsVariables>

SubscribeChannels subscription GraphQL query.

pub fn subscribe_accounts( selector: AccountSelector, ) -> StreamingOperation<SubscribeAccounts, AccountVariables>

SubscribeAccounts subscription GraphQL query.

pub fn subscribe_graph() -> StreamingOperation<SubscribeGraph, ()>

SubscribeGraph subscription GraphQL query.

pub fn subscribe_ticket_params() -> StreamingOperation<SubscribeTicketParams, ()>

SubscribeTicketParams subscription GraphQL query.

pub fn subscribe_health() -> StreamingOperation<SubscribeHealth, ()>

SubscribeHealth subscription GraphQL query.

pub fn subscribe_safe_deployments() -> StreamingOperation<SubscribeSafeDeployment, ()>

SubscribeSafeDeployment subscription GraphQL query.

pub fn subscribe_services( selector: ServiceSelector, ) -> StreamingOperation<SubscribeServices, ServiceVariables>

SubscribeServices subscription GraphQL query.

pub fn subscribe_service_types( service_type: Option<ServiceTypeId>, ) -> StreamingOperation<SubscribeServiceTypes, ServiceTypeVariables>

SubscribeServiceTypes subscription GraphQL query.

pub fn subscribe_service_registry_config() -> StreamingOperation<SubscribeServiceRegistryConfig, ()>

SubscribeServiceRegistryConfig subscription GraphQL query.

pub fn subscribe_ticket_redeemed( selector: TicketSelector, ) -> StreamingOperation<SubscribeTicketRedeemed, TicketRedeemedVariables>

SubscribeTicketRedeemed subscription GraphQL query.

pub fn subscribe_curvy_pending_notes( from_block: Option<u64>, ) -> StreamingOperation<SubscribeCurvyPendingNote, CurvyEventSubscriptionVariables>

Pending Curvy note subscription used for local ownership detection.

pub fn subscribe_curvy_committed_notes( from_block: Option<u64>, ) -> StreamingOperation<SubscribeCurvyCommittedNote, CurvyEventSubscriptionVariables>

Committed Curvy note subscription used for owned-note correlation.

pub fn subscribe_curvy_committed_nullifiers( from_block: Option<u64>, ) -> StreamingOperation<SubscribeCurvyCommittedNullifier, CurvyEventSubscriptionVariables>

Committed Curvy nullifier subscription.

Source

impl GraphQlQueries

pub fn mutate_submit_transaction( signed_tx: &[u8], ) -> Operation<MutateSendTransaction, SendTransactionVariables>

SendTransaction GraphQL mutation.

pub fn mutate_submit_and_track_transaction( signed_tx: &[u8], ) -> Operation<MutateTrackTransaction, SendTransactionVariables>

TrackTransaction GraphQL mutation.

pub fn mutate_submit_and_confirm_transaction( signed_tx: &[u8], confirmations: usize, ) -> Operation<MutateConfirmTransaction, ConfirmTransactionVariables>

ConfirmTransaction GraphQL mutation.

pub fn subscribe_track_transaction( tx_id: TxId, ) -> StreamingOperation<SubscribeTransaction, TransactionsVariables>

TrackTransaction GraphQL subscription.